@@ -1,6 +1,6 @@
 package Hubot::Scripts::redisBrain;
 {
-  $Hubot::Scripts::redisBrain::VERSION = '0.0.3';
+  $Hubot::Scripts::redisBrain::VERSION = '0.0.4';
 }
 use strict;
 use warnings;
@@ -13,7 +13,7 @@ sub load {
     my $coder = JSON::XS->new->convert_blessed;
     my $redis = Redis->new( server => $ENV{REDIS_SERVER} || '127.0.0.1:6379' );
     print "connected to redis-server\n" if $ENV{DEBUG};
-    my $json = $redis->get('hubot:storage');
+    my $json = $redis->get('hubot:storage') || '{}';
     $robot->brain->mergeData( decode_json( decode_utf8($json) ) );
     $robot->brain->on(
         'save',
